==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceObjectBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateInstanceObjectBuilder extends TemplateInstanceObjectFluentImpl<TemplateInstanceObjectBuilder> implements VisitableBuilder<TemplateInstanceObject,TemplateInstanceObjectBuilder>{
  public TemplateInstanceObjectBuilder() {
    this(false);
  }
  public TemplateInstanceObjectBuilder(Boolean validationEnabled) {
    this(new TemplateInstanceObject(), validationEnabled);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateInstanceObject(), validationEnabled);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,TemplateInstanceObject instance) {
    this(fluent, instance, false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,TemplateInstanceObject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRef(instance.getRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObject instance) {
    this(instance,false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObject instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRef(instance.getRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateInstanceObjectFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateInstanceObject build() {
    TemplateInstanceObject buildable = new TemplateInstanceObject(fluent.getRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceObjectBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateInstanceObjectBuilder extends TemplateInstanceObjectFluent<TemplateInstanceObjectBuilder> implements VisitableBuilder<TemplateInstanceObject,TemplateInstanceObjectBuilder>{
  public TemplateInstanceObjectBuilder() {
    this(false);
  }
  public TemplateInstanceObjectBuilder(Boolean validationEnabled) {
    this(new TemplateInstanceObject(), validationEnabled);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateInstanceObject(), validationEnabled);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,TemplateInstanceObject instance) {
    this(fluent, instance, false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObjectFluent<?> fluent,TemplateInstanceObject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TemplateInstanceObject());

    if (instance != null) {
      fluent.withRef(instance.getRef());
      fluent.withRef(instance.getRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObject instance) {
    this(instance,false);
  }
  public TemplateInstanceObjectBuilder(TemplateInstanceObject instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TemplateInstanceObject());

    if (instance != null) {
      this.withRef(instance.getRef());
      this.withRef(instance.getRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateInstanceObjectFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateInstanceObject build() {
    TemplateInstanceObject buildable = new TemplateInstanceObject(fluent.buildRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
